@@ -68,6 +68,8 @@ new LambdaToS3(scope: Construct, id: string, props: LambdaToS3Props);
 
 ## Pattern Properties
 
+| **Name**     | **Type**        | **Description** |
+|:-------------|:----------------|-----------------|
 |lambdaFunction|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Returns an instance of the Lambda function created by the pattern.|
 |s3Bucket|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of the S3 bucket created by the pattern.|
 
@@ -114,12 +116,29 @@ import aws_cdk.aws_s3
 import aws_cdk.core
 
 
-class LambdaToS3(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-solutions-constructs/aws-lambda-s3.LambdaToS3"):
+class LambdaToS3(
+    aws_cdk.core.Construct,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-solutions-constructs/aws-lambda-s3.LambdaToS3",
+):
     """
     summary:
     :summary:: The LambdaToS3 class.
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, deploy_lambda: bool, bucket_permissions: typing.Optional[typing.List[str]]=None, bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps]=None, deploy_bucket: typing.Optional[bool]=None, existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket]=None, existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function]=None, lambda_function_props: typing.Any=None) -> None:
+
+    def __init__(
+        self,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        *,
+        deploy_lambda: bool,
+        bucket_permissions: typing.Optional[typing.List[str]] = None,
+        bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        deploy_bucket: typing.Optional[bool] = None,
+        existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
+        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+        lambda_function_props: typing.Any = None,
+    ) -> None:
         """
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
@@ -138,7 +157,15 @@ class LambdaToS3(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aw
         summary:
         :summary:: Constructs a new instance of the LambdaToS3 class.
         """
-        props = LambdaToS3Props(deploy_lambda=deploy_lambda, bucket_permissions=bucket_permissions, bucket_props=bucket_props, deploy_bucket=deploy_bucket, existing_bucket_obj=existing_bucket_obj, existing_lambda_obj=existing_lambda_obj, lambda_function_props=lambda_function_props)
+        props = LambdaToS3Props(
+            deploy_lambda=deploy_lambda,
+            bucket_permissions=bucket_permissions,
+            bucket_props=bucket_props,
+            deploy_bucket=deploy_bucket,
+            existing_bucket_obj=existing_bucket_obj,
+            existing_lambda_obj=existing_lambda_obj,
+            lambda_function_props=lambda_function_props,
+        )
 
         jsii.create(LambdaToS3, self, [scope, id, props])
 
@@ -153,9 +180,31 @@ class LambdaToS3(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aw
         return jsii.get(self, "s3Bucket")
 
 
-@jsii.data_type(jsii_type="@aws-solutions-constructs/aws-lambda-s3.LambdaToS3Props", jsii_struct_bases=[], name_mapping={'deploy_lambda': 'deployLambda', 'bucket_permissions': 'bucketPermissions', 'bucket_props': 'bucketProps', 'deploy_bucket': 'deployBucket', 'existing_bucket_obj': 'existingBucketObj', 'existing_lambda_obj': 'existingLambdaObj', 'lambda_function_props': 'lambdaFunctionProps'})
-class LambdaToS3Props():
-    def __init__(self, *, deploy_lambda: bool, bucket_permissions: typing.Optional[typing.List[str]]=None, bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps]=None, deploy_bucket: typing.Optional[bool]=None, existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket]=None, existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function]=None, lambda_function_props: typing.Any=None) -> None:
+@jsii.data_type(
+    jsii_type="@aws-solutions-constructs/aws-lambda-s3.LambdaToS3Props",
+    jsii_struct_bases=[],
+    name_mapping={
+        "deploy_lambda": "deployLambda",
+        "bucket_permissions": "bucketPermissions",
+        "bucket_props": "bucketProps",
+        "deploy_bucket": "deployBucket",
+        "existing_bucket_obj": "existingBucketObj",
+        "existing_lambda_obj": "existingLambdaObj",
+        "lambda_function_props": "lambdaFunctionProps",
+    },
+)
+class LambdaToS3Props:
+    def __init__(
+        self,
+        *,
+        deploy_lambda: bool,
+        bucket_permissions: typing.Optional[typing.List[str]] = None,
+        bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        deploy_bucket: typing.Optional[bool] = None,
+        existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
+        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+        lambda_function_props: typing.Any = None,
+    ) -> None:
         """
         :param deploy_lambda: Whether to create a new Lambda function or use an existing Lambda function. If set to false, you must provide an existing function for the ``existingLambdaObj`` property. Default: - true
         :param bucket_permissions: Optional bucket permissions to grant to the Lambda function. One or more of the following may be specified: "Delete", "Put", "Read", "ReadWrite", "Write". Default: - Read/write access is given to the Lambda function if no value is specified.
@@ -168,16 +217,23 @@ class LambdaToS3Props():
         summary:
         :summary:: The properties for the LambdaToS3 class.
         """
-        if isinstance(bucket_props, dict): bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
+        if isinstance(bucket_props, dict):
+            bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
         self._values = {
-            'deploy_lambda': deploy_lambda,
+            "deploy_lambda": deploy_lambda,
         }
-        if bucket_permissions is not None: self._values["bucket_permissions"] = bucket_permissions
-        if bucket_props is not None: self._values["bucket_props"] = bucket_props
-        if deploy_bucket is not None: self._values["deploy_bucket"] = deploy_bucket
-        if existing_bucket_obj is not None: self._values["existing_bucket_obj"] = existing_bucket_obj
-        if existing_lambda_obj is not None: self._values["existing_lambda_obj"] = existing_lambda_obj
-        if lambda_function_props is not None: self._values["lambda_function_props"] = lambda_function_props
+        if bucket_permissions is not None:
+            self._values["bucket_permissions"] = bucket_permissions
+        if bucket_props is not None:
+            self._values["bucket_props"] = bucket_props
+        if deploy_bucket is not None:
+            self._values["deploy_bucket"] = deploy_bucket
+        if existing_bucket_obj is not None:
+            self._values["existing_bucket_obj"] = existing_bucket_obj
+        if existing_lambda_obj is not None:
+            self._values["existing_lambda_obj"] = existing_lambda_obj
+        if lambda_function_props is not None:
+            self._values["lambda_function_props"] = lambda_function_props
 
     @builtins.property
     def deploy_lambda(self) -> bool:
@@ -188,7 +244,7 @@ class LambdaToS3Props():
         default
         :default: - true
         """
-        return self._values.get('deploy_lambda')
+        return self._values.get("deploy_lambda")
 
     @builtins.property
     def bucket_permissions(self) -> typing.Optional[typing.List[str]]:
@@ -199,7 +255,7 @@ class LambdaToS3Props():
         default
         :default: - Read/write access is given to the Lambda function if no value is specified.
         """
-        return self._values.get('bucket_permissions')
+        return self._values.get("bucket_permissions")
 
     @builtins.property
     def bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
@@ -210,7 +266,7 @@ class LambdaToS3Props():
         default
         :default: - Default props are used
         """
-        return self._values.get('bucket_props')
+        return self._values.get("bucket_props")
 
     @builtins.property
     def deploy_bucket(self) -> typing.Optional[bool]:
@@ -221,7 +277,7 @@ class LambdaToS3Props():
         default
         :default: - true
         """
-        return self._values.get('deploy_bucket')
+        return self._values.get("deploy_bucket")
 
     @builtins.property
     def existing_bucket_obj(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
@@ -232,7 +288,7 @@ class LambdaToS3Props():
         default
         :default: - None
         """
-        return self._values.get('existing_bucket_obj')
+        return self._values.get("existing_bucket_obj")
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
@@ -243,7 +299,7 @@ class LambdaToS3Props():
         default
         :default: - None
         """
-        return self._values.get('existing_lambda_obj')
+        return self._values.get("existing_lambda_obj")
 
     @builtins.property
     def lambda_function_props(self) -> typing.Any:
@@ -254,7 +310,7 @@ class LambdaToS3Props():
         default
         :default: - Default properties are used.
         """
-        return self._values.get('lambda_function_props')
+        return self._values.get("lambda_function_props")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -263,7 +319,9 @@ class LambdaToS3Props():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'LambdaToS3Props(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "LambdaToS3Props(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
